@@ -481,7 +481,7 @@ void StoredSession::validate(const Application& app, const char* client_addr, ti
         return;
 
     if (!SPConfig::getConfig().isEnabled(SPConfig::OutOfProcess)) {
-        DDF in("touch::"STORAGESERVICE_SESSION_CACHE"::SessionCache"), out;
+        DDF in("touch::" STORAGESERVICE_SESSION_CACHE "::SessionCache"), out;
         DDFJanitor jin(in);
         in.structure();
         in.addmember("key").string(getID());
@@ -906,7 +906,7 @@ SessionCacheEx::~SessionCacheEx()
 }
 
 SSCache::SSCache(const DOMElement* e)
-    : m_log(Category::getInstance(SHIBSP_LOGCAT".SessionCache")), inproc(true),
+    : m_log(Category::getInstance(SHIBSP_LOGCAT ".SessionCache")), inproc(true),
 #ifndef SHIBSP_LITE
       m_storage(nullptr), m_storage_lite(nullptr), m_cacheAssertions(true), m_reverseIndex(true),
 #endif
@@ -991,9 +991,9 @@ SSCache::SSCache(const DOMElement* e)
 #ifndef SHIBSP_LITE
     else {
         if (listener && conf.isEnabled(SPConfig::OutOfProcess)) {
-            listener->regListener("find::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
-            listener->regListener("remove::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
-            listener->regListener("touch::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
+            listener->regListener("find::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
+            listener->regListener("remove::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
+            listener->regListener("touch::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
         }
         else {
             m_log.info("no ListenerService available, cache remoting disabled");
@@ -1019,9 +1019,9 @@ SSCache::~SSCache()
         SPConfig& conf = SPConfig::getConfig();
         ListenerService* listener=conf.getServiceProvider()->getListenerService(false);
         if (listener && conf.isEnabled(SPConfig::OutOfProcess)) {
-            listener->unregListener("find::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
-            listener->unregListener("remove::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
-            listener->unregListener("touch::"STORAGESERVICE_SESSION_CACHE"::SessionCache",this);
+            listener->unregListener("find::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
+            listener->unregListener("remove::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
+            listener->unregListener("touch::" STORAGESERVICE_SESSION_CACHE "::SessionCache",this);
         }
     }
 #endif
@@ -1040,8 +1040,14 @@ void SSCache::test()
 
 void SSCache::insert(const char* key, time_t expires, const char* name, const char* index, short attempts)
 {
-    if (attempts > 10)
+    if (attempts > 10) {
         throw IOException("Exceeded retry limit.");
+    }
+
+    if (!name || !*name) {
+        m_log.warn("NameID value was empty or null, ignoring request to store for logout");
+        return;
+    }
 
     string dup;
     unsigned int storageLimit = m_storage_lite->getCapabilities().getKeySize();
@@ -1233,7 +1239,8 @@ void SSCache::insert(
         throw FatalProfileException("Attempted to create a session with a duplicate key.");
 
     // Store the reverse mapping for logout.
-    if (nameid && m_reverseIndex && (m_excludedNames.size() == 0 || m_excludedNames.count(nameid->getName()) == 0)) {
+    if (name.get() && *name.get() && m_reverseIndex
+            && (m_excludedNames.size() == 0 || m_excludedNames.count(nameid->getName()) == 0)) {
         try {
             insert(key.get(), expires, name.get(), index.get());
         }
@@ -1571,7 +1578,7 @@ Session* SSCache::find(const Application& app, const char* key, const char* clie
         if (!SPConfig::getConfig().isEnabled(SPConfig::OutOfProcess)) {
             m_log.debug("session not found locally, remoting the search");
             // Remote the request.
-            DDF in("find::"STORAGESERVICE_SESSION_CACHE"::SessionCache"), out;
+            DDF in("find::" STORAGESERVICE_SESSION_CACHE "::SessionCache"), out;
             DDFJanitor jin(in);
             in.structure();
             in.addmember("key").string(key);
@@ -1793,7 +1800,7 @@ void SSCache::remove(const Application& app, const char* key)
     }
     else {
         // Remote the request.
-        DDF in("remove::"STORAGESERVICE_SESSION_CACHE"::SessionCache");
+        DDF in("remove::" STORAGESERVICE_SESSION_CACHE "::SessionCache");
         DDFJanitor jin(in);
         in.structure();
         in.addmember("key").string(key);
@@ -1853,10 +1860,16 @@ void* SSCache::cleanup_fn(void* p)
 
     // Load our configuration details...
     static const XMLCh cleanupInterval[] = UNICODE_LITERAL_15(c,l,e,a,n,u,p,I,n,t,e,r,v,a,l);
-    const XMLCh* tag=pcache->m_root ? pcache->m_root->getAttributeNS(nullptr, cleanupInterval) : nullptr;
+    const XMLCh* tag = pcache->m_root ? pcache->m_root->getAttributeNS(nullptr, cleanupInterval) : nullptr;
     int rerun_timer = 900;
     if (tag && *tag) {
-        rerun_timer = XMLString::parseInt(tag);
+        try {
+            rerun_timer = XMLString::parseInt(tag);
+        }
+        catch (XMLException&) {
+            pcache->m_log.error("cleanupInterval setting was not a numeric value");
+            rerun_timer = 0;
+        }
         if (rerun_timer <= 0)
             rerun_timer = 900;
     }
@@ -1921,7 +1934,7 @@ void SSCache::receive(DDF& in, ostream& out)
     if (!app)
         throw ListenerException("Application not found, check configuration?");
 
-    if (!strcmp(in.name(),"find::"STORAGESERVICE_SESSION_CACHE"::SessionCache")) {
+    if (!strcmp(in.name(),"find::" STORAGESERVICE_SESSION_CACHE "::SessionCache")) {
         const char* key=in["key"].string();
         if (!key)
             throw ListenerException("Required parameters missing for session lookup.");
@@ -1974,7 +1987,7 @@ void SSCache::receive(DDF& in, ostream& out)
         // Send the record back.
         out << record;
     }
-    else if (!strcmp(in.name(),"touch::"STORAGESERVICE_SESSION_CACHE"::SessionCache")) {
+    else if (!strcmp(in.name(),"touch::" STORAGESERVICE_SESSION_CACHE "::SessionCache")) {
         const char* key=in["key"].string();
         if (!key)
             throw ListenerException("Required parameters missing for session check.");
@@ -2086,7 +2099,7 @@ void SSCache::receive(DDF& in, ostream& out)
             out << ret;
         }
     }
-    else if (!strcmp(in.name(),"remove::"STORAGESERVICE_SESSION_CACHE"::SessionCache")) {
+    else if (!strcmp(in.name(),"remove::" STORAGESERVICE_SESSION_CACHE "::SessionCache")) {
         const char* key=in["key"].string();
         if (!key)
             throw ListenerException("Required parameter missing for session removal.");
